==> vue-mapbox-0.1.3.tgz: package/src/components/layer/CanvasLayer.js <==
import layerEvents from "../../lib/layerEvents";
import mixin from "./layerMixin";

export default {
  name: "CanvasLayer",
  mixins: [mixin],
  props: {
    canvas: {
      type: [HTMLCanvasElement, String],
      default: null
    },
    coordinates: {
      type: Array,
      required: true
    },
    animate: {
      type: Boolean,
      default: true
    },
    width: {
      type: Number,
      default: 100
    },
    height: {
      type: Number,
      default: 100
    }
  },

  computed: {
    canvasElement() {
      return this.mapSource ? this.mapSource.getCanvas() : null;
    }
  },

  watch: {
    minzoom(val) {
      if (this.initial) return;
      this.map.setLayerZoomRange(this.layerId, val, this.maxzoom);
    },
    maxzoom(val) {
      if (this.initial) return;
      this.map.setLayerZoomRange(this.layerId, this.minzoom, val);
    },
    coordinates(val) {
      if (this.initial) return;
      this.mapSource.setCoordinates(val);
    }
  },

  methods: {
    $_deferredMount(payload) {
      let canvasElement = this.canvas;
      if (!canvasElement) {
        canvasElement = document.createElement("canvas");
        canvasElement.id = this.sourceId;
        canvasElement.width = this.width;
        canvasElement.height = this.height;
      }

      const source = {
        type: "canvas",
        coordinates: this.coordinates,
        animate: this.animate,
        canvas: canvasElement
      };

      this.map = payload.map;
      this.map.on("dataloading", this.$_watchSourceLoading);
      try {
        this.map.addSource(this.sourceId, source);
      } catch (err) {
        if (this.replaceSource) {
          this.map.removeSource(this.sourceId);
          this.map.addSource(this.sourceId, source);
        } else {
          this.$_emitEvent("layer-source-error", {
            sourceId: this.sourceId,
            error: err
          });
        }
      }
      this.$_addLayer();
      this.$_bindLayerEvents(layerEvents);
      payload.component.$off("load", this.$_deferredMount);
      this.initial = false;
    },

    $_addLayer() {
      let existed = this.map.getLayer(this.layerId);
      if (existed) {
        if (this.replace) {
          this.map.removeLayer(this.layerId);
        } else {
          this.$_emitEvent("layer-exists", { layerId: this.layerId });
          return existed;
        }
      }
      let layer = {
        id: this.layerId,
        source: this.sourceId,
        type: "raster"
      };
      if (this.refLayer) {
        layer.ref = this.refLayer;
      } else {
        if (this["source-layer"]) {
          layer["source-layer"] = this["source-layer"];
        }
        if (this.minzoom) layer.minzoom = this.minzoom;
        if (this.maxzoom) layer.maxzoom = this.maxzoom;
      }
      layer.paint = this.paint ? this.paint : { "raster-opacity": 0.85 };
      layer.metadata = this.metadata;

      this.map.addLayer(layer, this.before);
      this.$_emitEvent("added", { layerId: this.layerId, canvas: this.canvas });
    }
  }
};

==> vue-mapbox-0.2.2.tgz: package/src/components/layer/CanvasLayer.js <==
import layerEvents from "../../lib/layerEvents";
import mixin from "./layerMixin";

export default {
  name: "CanvasLayer",
  mixins: [mixin],

  inject: ["mapbox", "map"],

  props: {
    source: {
      type: Object,
      required: true
    },
    layer: {
      type: Object,
      default: null
    }
  },

  computed: {
    canvasElement() {
      return this.mapSource ? this.mapSource.getCanvas() : null;
    }
  },

  watch: {
    coordinates(val) {
      if (this.initial) return;
      this.mapSource.setCoordinates(val);
    }
  },

  created() {
    this.$_deferredMount();
  },

  methods: {
    $_deferredMount() {
      const source = {
        type: "canvas",
        ...this.source
      };

      this.map.on("dataloading", this.$_watchSourceLoading);
      try {
        this.map.addSource(this.sourceId, source);
      } catch (err) {
        if (this.replaceSource) {
          this.map.removeSource(this.sourceId);
          this.map.addSource(this.sourceId, source);
        }
      }
      this.$_addLayer();
      this.$_bindLayerEvents(layerEvents);
      this.initial = false;
    },

    $_addLayer() {
      let existed = this.map.getLayer(this.layerId);
      if (existed) {
        if (this.replace) {
          this.map.removeLayer(this.layerId);
        } else {
          this.$_emitEvent("layer-exists", { layerId: this.layerId });
          return existed;
        }
      }
      let layer = {
        id: this.layerId,
        source: this.sourceId,
        type: "raster",
        ...this.layer
      };
      this.map.addLayer(layer, this.before);
      this.$_emitEvent("added", {
        layerId: this.layerId,
        canvas: this.canvasElement
      });
    }
  }
};
